@@ -13,6 +13,10 @@ mod std;
 // implementations should be moved into their respective crates over time. Before adding support for
 // another crate, please consider getting rkyv support in the crate instead.
 
+#[cfg(feature = "arrayvec")]
+mod arrayvec;
+#[cfg(feature = "bitvec")]
+mod bitvec;
 #[cfg(feature = "hashbrown")]
 mod hashbrown;
 #[cfg(feature = "indexmap")]
